#!perl

	use Acme::Labs;

BRAIN:	"Pinky, are you pondering what I'm pondering?"
PINKY:	"I think so, Brain, but Zero Mostel times anything will still give you Zero Mostel!"





	 EGaD EgAD ZOrT  poIT ZOrT EgAD egAD:: NArf Zort eGAD ZOrT  egAD ZOrT EgAD egAD EgAD => 1;
	
	 zoRT ZORt ZORT ZorT( " poIT ZOrT EgAD egAD ZORt zOrt ZorT  NARF ZoRT ZOrt ZOrT:: naRf ZORT zORT EgAD $ NARF ZoRT ZOrt ZOrT:: naRf ZORT zORT EgAD:: pOiT NArF pOIT PoIT NARf Narf nArf,  narf ZOrT eGAD zoRt $], $^ poiT" );

	 Zort ZoRt(1);
